@@ -2,9 +2,10 @@
 
 import logging
 
-from .posture import PrismaCloudAPIPosture
-from .code_security import PrismaCloudAPICodeSecurity
-from .compute import PrismaCloudAPICompute
+from .cspm import PrismaCloudAPICSPM
+from .cwpp import PrismaCloudAPICWPP
+from .pccs import PrismaCloudAPIPCCS
+
 from .pc_lib_utility import PrismaCloudUtility
 
 # --Description-- #
@@ -23,7 +24,7 @@ class CallCounter:
         return self.method(*args, **kwargs)
 
 # pylint: disable=too-many-instance-attributes
-class PrismaCloudAPI(PrismaCloudAPIPosture, PrismaCloudAPICompute, PrismaCloudAPICodeSecurity):
+class PrismaCloudAPI(PrismaCloudAPICSPM, PrismaCloudAPICWPP, PrismaCloudAPIPCCS):
     """ Prisma Cloud API Class """
     # pylint: disable=super-init-not-called
     def __init__(self):
